@@ -46,6 +46,9 @@ def clean(ctx, docs=True, bytecode=True, builds=True, ghuser=True):
             folders.append("build/")
             folders.extend(glob.glob("src/**/*.egg-info", recursive=False))
 
+        if ghuser and ctx.get("ghuser"):
+            folders.append(os.path.abspath(ctx.ghuser.target_dir))
+
         for folder in folders:
             shutil.rmtree(os.path.join(ctx.base_folder, folder), ignore_errors=True)
 
@@ -127,7 +130,7 @@ def build_ghuser_components(ctx, gh_io_folder=None, ironpython=None, prefix=None
                 compas_ghpython.fetch_ghio_lib(gh_io_folder)
 
             if not ironpython:
-                ironpython = "ipy"
+                ironpython = ctx.get("ironpython") or "ipy"
 
             gh_io_folder = os.path.abspath(gh_io_folder)
             componentizer_script = os.path.join(action_dir, "componentize.py")
